@@ -14,6 +14,7 @@ import sys
 import platform
 from typing import Optional
 from packaging import version
+import requests
 
 # Linux
 # ('Linux', '5.4.0-52-generic', '#57-Ubuntu SMP Thu Oct 15 10:57:00 UTC 2020')
@@ -22,10 +23,10 @@ from packaging import version
 # Darwin
 # ('Darwin', '19.6.0', 'Darwin Kernel Version 19.6.0: Thu Jun 18 20:49:00 PDT 2020; root:xnu-6153.141.1~1/RELEASE_X86_64')
 # 19.6.0
-print(platform.system())
-print(platform.system_alias(platform.system(), platform.release(), platform.version()))
-print(platform.release())
-print(platform.platform())
+# print(platform.system())
+# print(platform.system_alias(platform.system(), platform.release(), platform.version()))
+# print(platform.release())
+# print(platform.platform())
 
 app = typer.Typer(help="backplane CLI")
 
@@ -35,8 +36,20 @@ backplane_echo_prefix = "- "
 backplane = {}
 
 
+def getDynamicDomain():
+    f = requests.request("GET", "https://ifconfig.me")
+    ip = f.text
+
+    domain = f"{ip}.xip.io"
+    return domain
+
+
 @app.command()
-def install():
+def install(
+    domain: str = typer.Option(
+        getDynamicDomain(), "--domain", "-d", help="Backplane Domain"
+    ),
+):
     error = False
 
     # backplane['config_dir']
@@ -49,6 +62,7 @@ def install():
             )
         try:
             os.mkdir(backplane["config_dir"])
+            progress.update(250)
         except OSError as e:
             error = True
             typer.secho(
@@ -64,6 +78,7 @@ def install():
                     err=False,
                     fg=typer.colors.GREEN,
                 )
+
     else:
         if backplane["verbosity"] > 0:
             typer.secho(
@@ -97,6 +112,7 @@ def install():
                     err=False,
                     fg=typer.colors.GREEN,
                 )
+
     else:
         if backplane["verbosity"] > 0:
             typer.secho(
@@ -129,6 +145,7 @@ def install():
                     err=False,
                     fg=typer.colors.GREEN,
                 )
+
         except Exception as e:
             typer.secho(
                 f"Failed to clone backplane repository from {backplane_repo} to {backplane['default_context_dir']}: {e}",
@@ -152,27 +169,49 @@ def install():
     # make sure .env file exists
     if not os.path.exists(backplane["default_context_dir"] + "/.env"):
         if backplane["verbosity"] > 0:
-            typer.secho(f"default config does not exist", err=True, fg=typer.colors.RED)
+            typer.secho("default config does not exist", err=True, fg=typer.colors.RED)
 
-        try:
-            subprocess.run(
-                ["cp", ".env.example", ".env"], cwd=backplane["default_context_dir"]
-            )
-            if backplane["verbosity"] > 0:
-                typer.secho(
-                    f"Successfully created default config",
-                    err=False,
-                    fg=typer.colors.GREEN,
+        if backplane["environment"] == "development":
+            try:
+                subprocess.run(
+                    ["cp", ".env.example", ".env"],
+                    cwd=backplane["default_context_dir"],
                 )
-        except Exception as e:
-            error = True
-            typer.secho(
-                f"Failed to create default config: {e}", err=True, fg=typer.colors.RED
-            )
-            raise typer.Exit(code=1)
+                if backplane["verbosity"] > 0:
+                    typer.secho(
+                        "Successfully created default config",
+                        err=False,
+                        fg=typer.colors.GREEN,
+                    )
+
+            except Exception as e:
+                error = True
+                typer.secho(
+                    f"Failed to create default config: {e}",
+                    err=True,
+                    fg=typer.colors.RED,
+                )
+                raise typer.Exit(code=1)
+        else:
+            try:
+                with open(f"{backplane['default_context_dir']}/.env", "w") as writer:
+                    writer.write(
+                        f"BACKPLANE_DOMAIN={domain}\nBACKPLANE_ENVIRONMENT=production\n"
+                    )
+
+            except Exception as e:
+                error = True
+                typer.secho(
+                    f"Failed to create default config: {e}",
+                    err=True,
+                    fg=typer.colors.RED,
+                )
+                raise typer.Exit(code=1)
     else:
         if backplane["verbosity"] > 0:
-            typer.secho(f"default config exists", err=False, fg=typer.colors.GREEN)
+            typer.secho("default config exists", err=False, fg=typer.colors.GREEN)
+
+    # Update BACKPLANE_DOMAIN in .env file from "--domain"
 
     # Make sure Docker network "backplane" exists
     backplane_network_exists = False
@@ -199,6 +238,7 @@ def install():
                     err=False,
                     fg=typer.colors.GREEN,
                 )
+
         except Exception as e:
             error = True
             typer.secho(
@@ -210,7 +250,7 @@ def install():
     else:
         if backplane["verbosity"] > 0:
             typer.secho(
-                f"backplane Docker network exists", err=False, fg=typer.colors.GREEN
+                "backplane Docker network exists", err=False, fg=typer.colors.GREEN
             )
 
     if not error:
@@ -337,33 +377,34 @@ def start(
 ):
     backplane_services = services.split(",")
 
-    for service in backplane_services:
-        docker_compose_command = f"docker-compose -f docker-compose.yml -p backplane-{service} up -d --remove-orphans"
-        project_dir = os.path.join(
-            backplane["active_context_dir"], service, backplane["environment"]
-        )
-
-        if backplane["verbosity"] > 0:
-            typer.secho(
-                f"{docker_compose_command}", err=False, fg=typer.colors.BRIGHT_BLACK
+    with typer.progressbar(backplane_services, label="Starting") as progress:
+        for service in progress:
+            docker_compose_command = f"docker-compose -f docker-compose.yml -p backplane-{service} up -d --remove-orphans"
+            project_dir = os.path.join(
+                backplane["active_context_dir"], service, backplane["environment"]
             )
 
-        result = runCommand(docker_compose_command, project_dir)
-        if result.returncode != 0:
-            typer.secho(
-                f"Failed to start {service} in {backplane['active_context_dir']}: {result.stderr}",
-                err=True,
-                fg=typer.colors.RED,
-            )
-            raise typer.Exit(code=result)
-        else:
             if backplane["verbosity"] > 0:
                 typer.secho(
-                    f"Successfully started {service} in {backplane['active_context_dir']}",
-                    err=False,
-                    fg=typer.colors.GREEN,
+                    f"{docker_compose_command}", err=False, fg=typer.colors.BRIGHT_BLACK
                 )
 
+            result = runCommand(docker_compose_command, project_dir)
+            if result.returncode != 0:
+                typer.secho(
+                    f"Failed to start {service} in {backplane['active_context_dir']}: {result.stderr}",
+                    err=True,
+                    fg=typer.colors.RED,
+                )
+                raise typer.Exit(code=result)
+            else:
+                if backplane["verbosity"] > 0:
+                    typer.secho(
+                        f"Successfully started {service} in {backplane['active_context_dir']}",
+                        err=False,
+                        fg=typer.colors.GREEN,
+                    )
+
     status(services)
 
 
